@@ -221,6 +221,10 @@ class VersionAdmin(admin.ModelAdmin):
     
     def _hack_inline_formset_initial(self, FormSet, formset, obj, version, revert, recover):
         """Hacks the given formset to contain the correct initial data."""
+        # if the FK this inline formset represents is not being followed, don't process data for it.
+        # see https://github.com/etianen/django-reversion/issues/222
+        if formset.rel_name not in self.revision_manager.get_adapter(self.model).follow:
+            return
         # Now we hack it to push in the data from the revision!
         initial = []
         related_versions = self.get_related_versions(obj, version, FormSet)
